==> stylish-haskell-0.9.2.0-66-armv7h.pkg.tar.xz: usr/share/haskell/register/stylish-haskell.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stylish-haskell
version: 0.9.2.0
id: stylish-haskell-0.9.2.0-DztF26h8Lf19y0ajAdXUTw
key: stylish-haskell-0.9.2.0-DztF26h8Lf19y0ajAdXUTw
license: BSD-3-Clause
copyright: 2012 Jasper Van der Jeugt
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
author: Jasper Van der Jeugt <m@jaspervdj.be>
homepage: https://github.com/jaspervdj/stylish-haskell
synopsis: Haskell code prettifier
description:
    A Haskell code prettifier. For more information, see:
    .
    <https://github.com/jaspervdj/stylish-haskell/blob/master/README.markdown>
category: Language
abi: 14513edbb722d9e79573937697ab4721
exposed: True
exposed-modules:
    Language.Haskell.Stylish Language.Haskell.Stylish.Step.Imports
    Language.Haskell.Stylish.Step.LanguagePragmas
    Language.Haskell.Stylish.Step.SimpleAlign
    Language.Haskell.Stylish.Step.Squash
    Language.Haskell.Stylish.Step.Tabs
    Language.Haskell.Stylish.Step.TrailingWhitespace
    Language.Haskell.Stylish.Step.UnicodeSyntax
hidden-modules: Language.Haskell.Stylish.Align
                Language.Haskell.Stylish.Block Language.Haskell.Stylish.Config
                Language.Haskell.Stylish.Editor Language.Haskell.Stylish.Parse
                Language.Haskell.Stylish.Step Language.Haskell.Stylish.Util
                Language.Haskell.Stylish.Verbose Paths_stylish_haskell
import-dirs: /usr/lib/ghc-8.4.3/site-local/stylish-haskell-0.9.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/stylish-haskell-0.9.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/stylish-haskell
hs-libraries: HSstylish-haskell-0.9.2.0-DztF26h8Lf19y0ajAdXUTw
depends:
    aeson-1.4.0.0-EgUTCbIlE19378rsR2i9zV base-4.11.1.0
    bytestring-0.10.8.2 containers-0.5.11.0 directory-1.3.1.5
    filepath-1.4.2 file-embed-0.0.11-F0DApYaRQMkAdYGXjkQy01
    haskell-src-exts-1.20.2-G3Ml6HbnqnN7z120FmAg0n mtl-2.2.2
    syb-0.7-2jW43lwzJV5e7EQvU8PxV yaml-0.10.1.1-HSJRMGkYj0fJhvSvRDCAXR
abi-depends: aeson-1.4.0.0-EgUTCbIlE19378rsR2i9zV=8e4d597de977510ba6167651bfbacc4c
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             file-embed-0.0.11-F0DApYaRQMkAdYGXjkQy01=46cca7bb0548d8ae1738b3dc324c7440
             haskell-src-exts-1.20.2-G3Ml6HbnqnN7z120FmAg0n=9fc9240c296c3256ebefb2c3beb011a7
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=867165047495b4e6f144c8b9b108f918
             yaml-0.10.1.1-HSJRMGkYj0fJhvSvRDCAXR=a41d6b225d381f0049fc78adfb9171f0
haddock-interfaces: /usr/share/doc/stylish-haskell/html/stylish-haskell.haddock
haddock-html: /usr/share/doc/stylish-haskell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> stylish-haskell-0.9.2.0-67-armv7h.pkg.tar.xz: usr/share/haskell/register/stylish-haskell.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stylish-haskell
version: 0.9.2.0
id: stylish-haskell-0.9.2.0-oGdNZPzNpBLiONUGpkgjc
key: stylish-haskell-0.9.2.0-oGdNZPzNpBLiONUGpkgjc
license: BSD-3-Clause
copyright: 2012 Jasper Van der Jeugt
maintainer: Jasper Van der Jeugt <m@jaspervdj.be>
author: Jasper Van der Jeugt <m@jaspervdj.be>
homepage: https://github.com/jaspervdj/stylish-haskell
synopsis: Haskell code prettifier
description:
    A Haskell code prettifier. For more information, see:
    .
    <https://github.com/jaspervdj/stylish-haskell/blob/master/README.markdown>
category: Language
abi: 758a96aea95ee2586818a632dd113e8a
exposed: True
exposed-modules:
    Language.Haskell.Stylish Language.Haskell.Stylish.Step.Imports
    Language.Haskell.Stylish.Step.LanguagePragmas
    Language.Haskell.Stylish.Step.SimpleAlign
    Language.Haskell.Stylish.Step.Squash
    Language.Haskell.Stylish.Step.Tabs
    Language.Haskell.Stylish.Step.TrailingWhitespace
    Language.Haskell.Stylish.Step.UnicodeSyntax
hidden-modules: Language.Haskell.Stylish.Align
                Language.Haskell.Stylish.Block Language.Haskell.Stylish.Config
                Language.Haskell.Stylish.Editor Language.Haskell.Stylish.Parse
                Language.Haskell.Stylish.Step Language.Haskell.Stylish.Util
                Language.Haskell.Stylish.Verbose Paths_stylish_haskell
import-dirs: /usr/lib/ghc-8.4.3/site-local/stylish-haskell-0.9.2.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/stylish-haskell-0.9.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/stylish-haskell
hs-libraries: HSstylish-haskell-0.9.2.0-oGdNZPzNpBLiONUGpkgjc
depends:
    aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL base-4.11.1.0
    bytestring-0.10.8.2 containers-0.5.11.0 directory-1.3.1.5
    filepath-1.4.2 file-embed-0.0.11-F0DApYaRQMkAdYGXjkQy01
    haskell-src-exts-1.20.2-2zv4TjJLcP4GWvkOUtOP0Z mtl-2.2.2
    syb-0.7-2jW43lwzJV5e7EQvU8PxV yaml-0.10.1.1-6yEhnvvT8X92KHGOVP80PX
abi-depends: aeson-1.4.0.0-9WkSvHx7LJ453dlLjxz2kL=912860ab3519756596367ddae154025c
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             file-embed-0.0.11-F0DApYaRQMkAdYGXjkQy01=46cca7bb0548d8ae1738b3dc324c7440
             haskell-src-exts-1.20.2-2zv4TjJLcP4GWvkOUtOP0Z=60d4cdb6c821868fcfb451abd40f3254
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=867165047495b4e6f144c8b9b108f918
             yaml-0.10.1.1-6yEhnvvT8X92KHGOVP80PX=9e2767e1bb725b59ee794041072565ee
haddock-interfaces: /usr/share/doc/stylish-haskell/html/stylish-haskell.haddock
haddock-html: /usr/share/doc/stylish-haskell/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
